%global selfcheck 0
%define release_version %(echo %{version} | awk -F. '{print $1"_"$2"_"$3}')
%bcond_without python3
%bcond_without python3_debug
%if 0%{?selfcheck}
%bcond_without tests
%else
%bcond_with tests
%endif
Name:           python-psycopg2
Version:        2.9.6
Release:        1
Summary:        PostgreSQL database adapter for the Python programming language
License:        GPL-3.0-only and LGPL-3.0-only
URL:            http://www.psycopg.org/psycopg/
Source0:        https://github.com/psycopg/psycopg2/archive/%{version}.tar.gz#/psycopg2-%{version}.tar.gz

%global desc Psycopg is the most popular PostgreSQL adapter for the Python \
programming language. Its core is a complete implementation of the Python DB \
API 2.0 specifications. Several extensions allow access to many of the \
features offered by PostgreSQL.

%global python_runtimes %{?with_python3:python3 python3-debug}

%{!?with_python2:%{!?with_python3:%{error:one python version eneeded}}}

BuildRequires: gcc,postgresql-devel

%{?with_python3:BuildRequires:  python3-debug python3-devel}

%if %{with tests}
BuildRequires:  postgresql-test-rpm-macros
%endif
Conflicts:      python-psycopg2-zope < %{version}

%description
%{desc}



%package -n python3-psycopg2
Summary:        %{summary}
%{?python_provide:%python_provide python3-psycopg2 python3-psycopg2-binary}

%description  -n python3-psycopg2
%{desc}


%package -n python3-psycopg2-tests
Summary:      A testsuite for %{summary}
Requires:     python3-psycopg2 = %version-%release

%description -n python3-psycopg2-tests
%desc
This sub-package delivers set of tests for the adapter.

%package -n python3-psycopg2-debug
Summary:     A PostgreSQL database adapter for Python 3 (debug build)
Requires:    python3-psycopg2 = %{version}-%{release}

%description -n python3-psycopg2-debug
This is a build of the psycopg PostgreSQL database adapter for the debug
build of Python 3.


%package doc
Summary:        Documentation for psycopg python PostgreSQL database adapter
Requires:       %{name} = %{version}-%{release}
%{?with_python3:Provides: python3-psycopg2-doc = %{version}-%{release}}

%description doc
Documentation and example files for the psycopg python PostgreSQL
database adapter.

%prep
%autosetup -p1 -n psycopg2-%{version}


%build
export CFLAGS=${RPM_OPT_FLAGS} LDFLAGS=${RPM_LD_FLAGS}
for python in %{python_runtimes} ; do
  $python setup.py build
done

for i in `find doc -iname "*.html"`; do sed -i 's/\r//' $i; done
for i in `find doc -iname "*.css"`; do sed -i 's/\r//' $i; done
rm -f doc/html/.buildinfo

%check
%if %{with tests}
export PGTESTS_LOCALE=C.UTF-8
%postgresql_tests_run

export PSYCOPG2_TESTDB=${PGTESTS_DATABASES##*:}
export PSYCOPG2_TESTDB_HOST=$PGHOST
export PSYCOPG2_TESTDB_PORT=$PGPORT
cmd="import tests; tests.unittest.main(defaultTest='tests.test_suite')"

PYTHONPATH=%buildroot%python3_sitearch %__python3 -c "$cmd" --verbose
%endif

%install
export CFLAGS=${RPM_OPT_FLAGS} LDFLAGS=${RPM_LD_FLAGS}
for python in %{python_runtimes} ; do
  $python setup.py install --no-compile --root %{buildroot}
done

cp -r tests/ %{buildroot}%{python3_sitearch}/psycopg2/tests/
for i in `find %{buildroot}%{python3_sitearch}/psycopg2/tests/ -iname "*.py"`; do
  sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|' $i
done


%files -n python3-psycopg2
%license LICENSE
%doc AUTHORS NEWS README.rst
%dir %{python3_sitearch}/psycopg2
%{python3_sitearch}/psycopg2/*.py
%{python3_sitearch}/psycopg2/_psycopg.cpython-3??[!d]*.so
%dir %{python3_sitearch}/psycopg2/__pycache__
%{python3_sitearch}/psycopg2/__pycache__/*.py{c,o}
%{python3_sitearch}/psycopg2-%{version}-py3*.egg-info


%files -n python3-psycopg2-tests
%{python3_sitearch}/psycopg2/tests

%files -n python3-psycopg2-debug
%license LICENSE
%{python3_sitearch}/psycopg2/_psycopg.cpython-3*d*.so

%files doc
%license LICENSE
%doc doc

%changelog
* Tue Apr 4 2023 wubijie <wubijie@kylinos.cn> - 2.9.6-1
- Update package to version 2.9.6

* Wed Mar 01 2023 wangxiyuan <wangxiyuan1007@gmail.com> - 2.9.5-2
- Add python3-psycopg2-binary provide

* Wed Nov 09 2022 jiangxinyu <jiangxinyu@kylinos.cn> - 2.9.5-1
- Upgrade package to version 2.9.5

* Wed Aug 03 2022 kkz <zhaoshuang@uniontech.com> -2.9.3-1
- update to 2.9.3

* Sat May 07 2022 renxichen <renhongxun@h-partnsers.com> - 2.8.6-2
- fix packaging error on _psycopg.cpython-*.so

* Wed Jul 28 2021 liksh <liks11@chinaunicom.cn> -2.8.6-1
- update to 2.8.6

* Mon Jul 26 2021 zhouwenpei <zhouwenpei1@huawei.com> - 2.8.4-3
- modify build require and fix licenses failed

* Thu Oct 29 2020 xinghe <xinghe1@huawei.com> - 2.8.4-2
- remove python2 dependency

* Sat Jun 20 2020 Jeffery.Gao <gaojianxing@huawei.com> - 2.8.4-1
- Upgrade package & fixed build as root errors

* Tue Mar 10 2020 chenli <chenli147@huawei.com> - 2.7.5-3.2
- Fix python2-psycopg2-tests install error

* Wed Feb 12 2020 openEuler Buildteam <buildteam@openeuler.org> - 2.7.5-3.1
- Package init
